import QtQuick 2.0
import QtQuick.Layouts 1.3

import "Config.js" as Conf
import "Translations.js" as Translations

Item
{
    id: parentItem
    property int    loadLevelValue : -1
    property bool   loadLevelTextEnable
    property bool   loadLevelTextColorful
    property bool   loadLevelTextLong
    property int    loadLevelTextFontSize
    property color  loadLevelTextColorDefault
    property color  loadLevelTextColorGreen
    property color  loadLevelTextColorYellow
    property color  loadLevelTextColorRed
    property string loadLevelTextFontFamily

    property bool loadLevelTextFontWeight
    property bool loadLevelTextUnitFontBold

    property bool loadLevelIconEnable
    property int  loadLevelIconXPosition
    property int  loadLevelIconYPosition
    property int  loadLevelIconWidth
    property int  loadLevelIconHeight
    property int  loadLevelItemsSpacing

    property bool loadLevelRingVisible
    property int loadLevelRingSize

    property int paintedWidth


    function makeTextBoldForNeed( text, need )
    {
        if( need )
            return "<b>" + text + "</b>";
        else
            return text;
    }

    onLoadLevelValueChanged: {
        if (loadLevelIconItem.visible) {
            paintedWidth = loadLevelIconItem.paintedWidth
        } else {
            paintedWidth = 0
        }

        loadLevelLongTextItem.visible = ( (loadLevelTextEnable && loadLevelValue >= 0) || loadLevelTextLong )
        loadLevelLongTextItem.text = ""
        if (loadLevelValue >= 0) {
            if (loadLevelTextEnable) {
                loadLevelLongTextItem.text = makeTextBoldForNeed(loadLevelValue, loadLevelTextUnitFontBold)
            }
            if( loadLevelTextLong ) {
                loadLevelLongTextItem.text += " " + makeTextBoldForNeed( Translations["ball"][Conf.Locale][loadLevelValue], loadLevelTextFontWeight )
            }
        }

        if (loadLevelLongTextItem.visible) {
            paintedWidth += loadLevelLongTextItem.paintedWidth
        }
        if (loadLevelTextItemRing.visible) {
            paintedWidth += loadLevelTextItemRing.paintedWidth
        }
        paintedWidth += (Number(loadLevelIconItem.visible) + Number(loadLevelTextItemRing.visible) + Number(loadLevelLongTextItem.visible) -1) * loadLevelItemsSpacing
    }

    RowLayout {
        id: row
       // x: 10
       // y: 5
        x: loadLevelIconXPosition
        y: loadLevelIconYPosition
        //width: parent.width
        //height: parent.height
        spacing: loadLevelItemsSpacing

        Image
        {
            id: loadLevelIconItem
            //x: loadLevelIconXPosition
            //y: loadLevelIconYPosition
            ///width: loadLevelIconWidth
            ///height: loadLevelIconHeight
            Layout.preferredWidth: loadLevelIconWidth
            Layout.preferredHeight: loadLevelIconHeight
            cache: false

            source: {
                if( Conf.CityLoadImageTrafficDay )
                {
                    if( Conf.CityLoadImageTrafficDirection )
                    {
                        if( loadLevelValue >= 0 && loadLevelValue <= 3 ) "images/green_traffic_day_left.png"
                        else if ( loadLevelValue >= 4 && loadLevelValue <= 6 ) "images/yellow_traffic_day_left.png"
                        else if ( loadLevelValue >=7 && loadLevelValue <=10 ) "images/red_traffic_day_left.png"
                        else "";
                    }
                    else
                    {
                        if( loadLevelValue >= 0 && loadLevelValue <= 3 ) "images/green_traffic_day_right.png"
                        else if ( loadLevelValue >= 4 && loadLevelValue <= 6 ) "images/yellow_traffic_day_right.png"
                        else if ( loadLevelValue >=7 && loadLevelValue <=10 ) "images/red_traffic_day_right.png"
                        else "";
                    }
                }
                else
                {
                    if( Conf.CityLoadImageTrafficDirection )
                    {
                        if( loadLevelValue >= 0 && loadLevelValue <= 3 ) "images/green_traffic_night_left.png"
                        else if ( loadLevelValue >= 4 && loadLevelValue <= 6 ) "images/yellow_traffic_night_left.png"
                        else if ( loadLevelValue >=7 && loadLevelValue <=10 ) "images/red_traffic_night_left.png"
                        else "";
                    }
                    else
                    {
                        if( loadLevelValue >= 0 && loadLevelValue <= 3 ) "images/green_traffic_night_right.png"
                        else if ( loadLevelValue >= 4 && loadLevelValue <= 6 ) "images/yellow_traffic_night_right.png"
                        else if ( loadLevelValue >=7 && loadLevelValue <=10 ) "images/red_traffic_night_right.png"
                        else "";
                    }
                }
            }
            visible : ( loadLevelIconEnable && loadLevelValue >= 0 )
        }

        Image
        {
            id: loadLevelTextItemRing
            visible: loadLevelRingVisible
            source: {
                if( loadLevelValue >= 0 && loadLevelValue <= 10 ) "images/highway_load_" + loadLevelValue + ".png"
                else "";
            }
            //x: loadLevelRingPosX
            //y: loadLevelRingPosY
            horizontalAlignment: Image.AlignHCenter
            verticalAlignment: Image.AlignVCenter
            fillMode: Image.Stretch
            cache: false
            Layout.preferredWidth: loadLevelRingSize - 1
            Layout.preferredHeight: loadLevelRingSize - 1
        }

        ColorfulText
        {
            id: loadLevelLongTextItem
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font.pointSize: loadLevelTextFontSize - 1
            font.family: loadLevelTextFontFamily

            isColorful: loadLevelTextColorful
            loadlLevelValue: loadLevelValue
            colorDefault: loadLevelTextColorDefault
            colorGreen: loadLevelTextColorGreen
            colorYellow: loadLevelTextColorYellow
            colorRed: loadLevelTextColorRed

            //x: loadLevelTextLongX
            //y: loadLevelTextLongY

        }
    }



}
